package org.jtheque.core.managers;

import org.jtheque.core.managers.log.IJThequeLogger;
import org.jtheque.core.managers.log.ILoggingManager;
import org.jtheque.core.managers.error.IErrorManager;
import org.jtheque.core.managers.state.IStateManager;
import org.jtheque.core.managers.language.ILanguageManager;

import org.jdesktop.swingx.event.WeakEventListenerList;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * An abstract manager. 
 * 
 * @author Baptiste Wicht
 */
public abstract class AbstractManager implements IManager {
    private static final WeakEventListenerList LISTENERS = new WeakEventListenerList();

    /**
     * Return the listeners of the manager. 
     * 
     * @return The listeners of the manager. 
     */
    protected static WeakEventListenerList getListeners() {
        return LISTENERS;
    }

    /**
     * Return the logger of the manager. 
     * 
      * @return The logger of the manager. 
     */
    protected final IJThequeLogger getLogger(){
        return Managers.getManager(ILoggingManager.class).getLogger(getClass());
    }

    /**
     * Return the error manager. 
     * 
     * @return The error manager. 
     */
    protected static IErrorManager getErrors(){
        return Managers.getManager(IErrorManager.class);
    }

    /**
     * Return the state manager. 
     * 
     * @return The state manager. 
     */
    protected static IStateManager getStates(){
        return Managers.getManager(IStateManager.class);
    }

    /**
     * Return the internationalized message. 
     * 
     * @param key The internationalization key. 
     * 
     * @return The internationalized message. 
     */
    protected static String getMessage(String key){
        return Managers.getManager(ILanguageManager.class).getMessage(key);
    }

    /**
     * Return the internationalized message. 
     * 
     * @param key The internationalization key. 
     * @param replaces The objects to use for the replaces. 
     * 
     * @return The internationalized message. 
     */
    protected static String getMessage(String key, Object... replaces) {
        return Managers.getManager(ILanguageManager.class).getMessage(key, replaces);
    }
}