package org.jtheque.core.managers.core.application;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *
 * @author Baptiste Wicht
 */
public abstract class AbstractApplication implements Application {
    private String folderPath;
    private String licenceFilePath;
    private String applicationLogoFile;
    private String applicationBaseName;
    private String applicationRepository;
    private String applicationMessageFileURL;

    private String email;
    private String copyright;

    private boolean displayLicence;
    private String logo;

    private final String author;
    private final String applicationName;
    private final String site;

    /**
     * Construct a new AbstractApplication. 
     * 
     * @param author The author of the application. 
     * @param site The site url of the application. 
     * @param applicationName The name of the application. 
     */
    protected AbstractApplication(String author, String site, String applicationName) {
        super();

        this.author = author;
        this.site = site;
        this.applicationName = applicationName;
    }

    @Override
    public final String getLogoFile() {
        return applicationLogoFile;
    }

    /**
     * Set the path to the application logo file. 
     * 
     * @param applicationLogoFile The path to the application's logo file. 
     */
    protected final void setApplicationLogoFile(String applicationLogoFile) {
        this.applicationLogoFile = applicationLogoFile;
    }

    @Override
    public final String getLicenceFilePath() {
        return licenceFilePath;
    }

    /**
     * Set the path to the licence file. 
     * 
     * @param licenceFilePath The licence file path. 
     */
    protected final void setLicenceFilePath(String licenceFilePath) {
        this.licenceFilePath = licenceFilePath;
    }

    @Override
    public final String getFolderPath() {
        return folderPath;
    }

    /**
     * Set the path to the current folder. 
     * 
     * @param folderPath The path to the current folder. 
     */
    protected final void setFolderPath(String folderPath) {
        this.folderPath = folderPath;
    }

    @Override
    public final String getBaseName() {
        return applicationBaseName;
    }

    /**
     * Set the application i18n base name. 
     * 
     * @param applicationBaseName The basename of the application. 
     */
    protected final void setApplicationBaseName(String applicationBaseName) {
        this.applicationBaseName = applicationBaseName;
    }

    /**
     * Indicate if we must display the licence or not. 
     * 
     * @param displayLicence A boolean flag indicating if we must display the licence or not. true if we must
     * display the licence else false. 
     */
    protected final void setDisplayLicence(boolean displayLicence) {
        this.displayLicence = displayLicence;
    }

    @Override
    public final boolean isDisplayLicence() {
        return displayLicence;
    }

    @Override
    public final String getRepository() {
        return applicationRepository;
    }

    /**
     * Set the application repository. 
     * 
     * @param applicationRepository The application repository. 
     */
    protected final void setApplicationRepository(String applicationRepository) {
        this.applicationRepository = applicationRepository;
    }

    @Override
    public final String getMessageFileURL() {
        return applicationMessageFileURL;
    }

    /**
     * Set the application messages file URL. 
     * 
     * @param applicationMessageFileURL The application messages file URL. 
     */
    protected final void setApplicationMessageFileURL(String applicationMessageFileURL) {
        this.applicationMessageFileURL = applicationMessageFileURL;
    }

    @Override
    public final String getPNGLogo() {
        return logo;
    }

    /**
     * Set the PNG logo. 
     * 
     * @param logo The PNG logo file. 
     */
    protected final void setPNGLogo(String logo) {
        this.logo = logo;
    }

    @Override
    public final String getName() {
        return applicationName;
    }

    @Override
    public final String getAuthor() {
        return author;
    }

    @Override
    public final String getEmail() {
        return email;
    }

    /**
     * Set the email of the author. 
     * 
     * @param email The email of the author. 
     */
    protected final void setEmail(String email) {
        this.email = email;
    }

    @Override
    public final String getSite() {
        return site;
    }

    @Override
    public final String getCopyright() {
        return copyright;
    }

    /**
     * Set the copyright of the application. 
     * 
     * @param copyright The copyright of the application. 
     */
    protected final void setCopyright(String copyright) {
        this.copyright = copyright;
    }
}