package org.jtheque.core.managers.lifecycle.phases;

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.beans.ioc.Ioc;
import org.jtheque.core.managers.view.IViewManager;
import org.jtheque.core.managers.module.IModuleManager;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.managers.language.Internationalizable;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * The first phase of the JTheque life cycle. 
 * 
 * @author Baptiste Wicht
 */
public final class FirstPhase implements LifeCyclePhase {
    @Override
    public void run() {
        displaySplashScreen();

        Managers.preInitManagers();

        Managers.getManager(ILanguageManager.class).addInternationalizable((Internationalizable) Managers.getCore().getLifeCycleManager());

        Managers.getManager(IModuleManager.class).choosePrimaryModule();
    }

    /**
     * Display the splash screen.  
     */
    private static void displaySplashScreen(){
        IViewManager manager = (IViewManager) Ioc.getContainer().getApplicationContext().getBean("viewManager");

        manager.getViews().displayMainView();
        manager.displaySplashScreen();
    }
}
