package org.jtheque.core.managers.persistence;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.ActivableManager;
import org.jtheque.core.managers.persistence.able.DataContainer;

/**
 * A persistence manager. It seems the manager who's responsible for the persistence of the work entities. This
 * manager provide methods to manage entities and to open secondary connection.
 *
 * @author Baptiste Wicht
 */
public interface IPersistenceManager extends ActivableManager {
    /**
     * Add a DAO to clear after the restore process.
     *
     * @param dao The DAO to add.
     */
    void addDaoToClearOnRestore(DataContainer<? extends Entity> dao);

    /**
     * Remove a DAO to clear after the restore process.
     *
     * @param dao The DAO to remove.
     */
    void removeDaoToClearOnRestore(DataContainer<? extends Entity> dao);

    /**
     * Clear the database.
     */
    void clearDatabase();
}