package org.jtheque.core.managers.properties;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import java.lang.reflect.Method;

/**
 * A Property.
 *
 * @author Baptiste Wicht
 */
public final class Property {
    private String name;
    private Method getter;
    private Method setter;

    /**
     * Return the name of the property.
     *
     * @return The name of the property.
     */
    public String getName() {
        return name;
    }

    /**
     * Set the name of the property.
     *
     * @param name The name of the property.
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Return the getter method.
     *
     * @return The getter method.
     */
    public Method getGetter() {
        return getter;
    }

    /**
     * Set the getter method.
     *
     * @param getter The getter method.
     */
    public void setGetter(Method getter) {
        this.getter = getter;
    }

    /**
     * Return the setter method.
     *
     * @return The setter method.
     */
    public Method getSetter() {
        return setter;
    }

    /**
     * Set the setter method.
     *
     * @param setter The setter method.
     */
    public void setSetter(Method setter) {
        this.setter = setter;
    }

    @Override
    public String toString() {
        return "Property{" +
                "name='" + name + '\'' +
                ", getter=" + getter +
                ", setter=" + setter +
                '}';
    }
}