package org.jtheque.core.managers.resource;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.view.impl.actions.JThequeAction;

import org.springframework.core.io.Resource;

import javax.swing.ImageIcon;
import java.awt.image.BufferedImage;
import java.awt.Color;
import java.io.InputStream;

/**
 * A resource manager.
 *
 * @author Baptiste Wicht
 */
public interface IResourceManager {
    /**
     * Return the ressource of the path. 
     * 
     * @param path The path to the ressource. 
     * 
     * @return The loaded Ressource. 
     */
    Resource getResource(String path);

    /**
     * Return the ressource as stream. 
     * 
     * @param path The path to the ressource. 
     * 
     * @return The inputstream of the loaded ressource. 
     */
    InputStream getResourceAsStream(String path);

    /**
     * Load and return the icon. 
     * 
     * @param basename The images basename. 
     * @param id The image index. 
     * @param type The image type. 
     * 
     * @return The loaded icon. 
     */
    ImageIcon getIcon(String basename, String id, ImageType type);

    /**
     * Load and return the icon. 
     * 
     * @param id The image index. 
     * @param type The image type. 
     * 
     * @return The loaded icon. 
     */
    ImageIcon getIcon(String id, ImageType type);
    
    /**
     * Load and return the icon. 
     * 
     * @param id The image index. 
     * 
     * @return The loaded icon. 
     */
    ImageIcon getIcon(String id);

    /**
     * Load, return and resize the image. 
     * 
     * @param basename The image base name. 
     * @param id The image index. 
     * @param type The image type. 
     * @param width The width. 
     * 
     * @return The loaded icon. 
     */
    BufferedImage getImage(String basename, String id, ImageType type, int width);

    /**
     * Load and return the image. 
     * 
     * @param basename The image base name. 
     * @param id The image index. 
     * @param type The image type. 
     * 
     * @return The loaded icon. 
     */
    BufferedImage getImage(String basename, String id, ImageType type);

    /**
     * Load, return and resize the image. 
     * 
     * @param id The image index. 
     * @param type The image type. 
     * @param width The width. 
     * 
     * @return The loaded icon. 
     */
    BufferedImage getImage(String id, ImageType type, int width);

    /**
     * Load and return the image. 
     * 
     * @param id The image index. 
     * @param type The image type. 
     * 
     * @return The loaded icon. 
     */
    BufferedImage getImage(String id, ImageType type);

    /**
     * Load, return and resize the image. 
     * 
     * @param id The image index. 
     * @param width The width. 
     * 
     * @return The loaded icon. 
     */
    BufferedImage getImage(String id, int width);

    /**
     * Load and return the image. 
     * 
     * @param id The image index. 
     * 
     * @return The loaded icon. 
     */
    BufferedImage getImage(String id);

    /**
     * Return the color of the specified name. 
     * 
     * @param name The name of the color. 
     * 
     * @return The color of the specified name. 
     */
    Color getColor(String name);

    /**
     * Return the action of the specified name. 
     * 
     * @param name The name of the color. 
     * 
     * @return The action of the specified name. 
     */
    JThequeAction getAction(String name);
}