package org.jtheque.core.managers.update.actions;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.log.ILoggingManager;
import org.jtheque.utils.io.FileUtils;
import org.jtheque.utils.io.FileException;

/**
 * An update action that download a file.
 *
 * @author Baptiste Wicht
 */
public final class DownloadAction extends AbstractUpdateAction {
    private String url;

    @Override
    public void execute() {
        try {
            FileUtils.downloadFile(url, getDestination());
        } catch (FileException e) {
            Managers.getManager(ILoggingManager.class).getLogger(getClass()).exception(e);
        }
    }

    /**
     * Set the URL of the file to download.
     *
     * @param url The URL.
     */
    public void setUrl(String url) {
        this.url = url;
    }
}