package org.jtheque.core.managers.view.impl.components.model;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.skin.ISkinManager;
import org.jtheque.core.managers.skin.Skin;

import javax.swing.DefaultComboBoxModel;

/**
 * A combobox model of available look and feels.
 *
 * @author Baptiste Wicht
 */
public final class AvailableLookAndFeelsComboBoxModel extends DefaultComboBoxModel {
    private static final long serialVersionUID = -4951122212082229878L;

    private final ISkinManager skin;

    /**
     * Construct a new AvailableLookAndFeelsComboBoxModel.
     */
    public AvailableLookAndFeelsComboBoxModel() {
        super();

        skin = Managers.getManager(ISkinManager.class);
    }

    @Override
    public Object getElementAt(int index) {
        return skin.getSkins().get(index);
    }

    @Override
    public int getSize() {
        return skin.getSkins().size();
    }

    /**
     * Return the selected look and feel.
     *
     * @return The selected look and feel.
     */
    public Skin getSelectedSkin() {
        return (Skin) getSelectedItem();
    }
}