package org.jtheque.core.managers.view.impl.models;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.message.IMessageManager;
import org.jtheque.core.managers.message.Message;
import org.jtheque.utils.bean.IntDate;

/**
 * A model for the messages view.
 *
 * @author Baptiste Wicht
 */
public final class MessageModel {
    private int current;
    private final IMessageManager manager;
    private final Message defaultMessage;

    /**
     * Construct a new MessageModel.
     */
    public MessageModel() {
        super();

        manager = Managers.getManager(IMessageManager.class);

        defaultMessage = new Message();
        defaultMessage.setDate(IntDate.today());
        defaultMessage.setId(-1);
        defaultMessage.setSource("");
        defaultMessage.setMessage("");
        defaultMessage.setTitle("");
    }

    /**
     * Return the next message to display.
     *
     * @return The next message to display.
     */
    public Message getNextMessage() {
        current++;

        if (current >= manager.getMessages().size()) {
            current = 0;
        }

        return manager.getMessages().isEmpty() ? defaultMessage : manager.getMessages().get(current);
    }

    /**
     * Return the current message.
     *
     * @return The current message.
     */
    public Message getCurrentMessage() {
        return manager.getMessages().isEmpty() ? defaultMessage : manager.getMessages().get(current);
    }

    /**
     * Return the previous message.
     *
     * @return The previous message.
     */
    public Message getPreviousMessage() {
        current--;

        if (current < 0) {
            current = manager.getMessages().size() - 1;
        }

        return manager.getMessages().isEmpty() ? defaultMessage : manager.getMessages().get(current);
    }

    /**
     * Indicate if the model is currently displaying the default message or a real message. 
     * 
     * @return true if the current message is the default message else false. 
     */
    public boolean isDefaultMessage(){
        return manager.getMessages().isEmpty();
    }
}
