package org.jtheque.core.utils.db;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.utils.db.DaoNotes.NoteType;
import org.jtheque.utils.EqualsUtils;
import org.jtheque.utils.Constants;

/**
 * A note.
 *
 * @author Baptiste Wicht
 */
public final class Note {
    private final String key;
    private final NoteType value;

    /**
     * Construct a new NoteImpl with a specific value and a text key.
     *
     * @param value The value of the note.
     * @param key   The text key.
     */
    public Note(NoteType value, String key) {
        super();

        this.value = value;
        this.key = key;
    }

    /**
     * Return the internationalized text of the note.
     *
     * @return A text representation of the note.
     */
    public String getInternationalizedText() {
        return Managers.getManager(ILanguageManager.class).getMessage(key);
    }

    @Override
    public String toString() {
        return getInternationalizedText();
    }

    @Override
    public int hashCode() {
        int result = Constants.HASH_CODE_START;

        result = Constants.HASH_CODE_PRIME * result + value.intValue();
        result = Constants.HASH_CODE_PRIME * result + (key == null ? 0 : key.hashCode());

        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }

        if(EqualsUtils.areObjectIncompatible(this, obj)){
            return false;
        }

        final Note other = (Note) obj;

        if (value != other.value) {
            return false;
        }

        return !EqualsUtils.areNotEquals(key, other.key);

    }

    /**
     * Return the element name of the note.
     *
     * @return The element name.
     */
    public String getElementName() {
        return getInternationalizedText();
    }

    /**
     * Return the value of the note.
     *
     * @return The int value of note.
     */
    public NoteType getValue() {
        return value;
    }
}